/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2010 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 *  GPLv3 + Classpath exception
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package it.geosolutions.geoserver.rest.decoder;

import it.geosolutions.geoserver.rest.decoder.utils.JDOMListIterator;

import it.geosolutions.geoserver.rest.decoder.utils.NameLinkElem;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import org.jdom.Element;

/**
 * Parses list of summary data.
 *
 * <P>This is the XML REST representation:
 * <PRE>
  {@code
<ELEMENTs>
      <ELEMENT>
        <name>elem1</name>
        <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate" href="url1" type="application/xml"/>
      </ELEMENT>
      <ELEMENT>
        <name>elem2</name>
        <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate" href="url2" type="application/xml"/>
      </ELEMENT>
</ELEMENTs>
}</PRE>
 *
 * @author ETj (etj at geo-solutions.it)
 */
public class RESTAbstractList<ELEM extends NameLinkElem> implements Iterable<ELEM> {

    protected final List<Element> elementList;

    protected RESTAbstractList(Element list) {
        List<Element> tempList = new ArrayList<Element>();
        String baseName = null;

        for (Element listItem : (List<Element>) list.getChildren()) {
            if(baseName == null)
                baseName = listItem.getName();
            else
                if(! baseName.equals(listItem.getName())) {
                    throw new RuntimeException("List elements mismatching (" + baseName+","+listItem.getName()+")");
                }

            tempList.add(listItem);
        }

        elementList = Collections.unmodifiableList(tempList);
    }

    public int size() {
        return elementList.size();
    }

    public boolean isEmpty() {
        return elementList.isEmpty();
    }

    public ELEM get(int index) {
        return createElement(elementList.get(index));
    }

    public Iterator<ELEM> iterator() {
        return new RESTAbstractListIterator(elementList);
    }

    public List<String> getNames() {
        List<String> names = new ArrayList<String>(elementList.size());
        for (ELEM elem: this) {
            names.add(elem.getName());
        }
        return names;
    }


    private class RESTAbstractListIterator extends JDOMListIterator<ELEM> {

        public RESTAbstractListIterator(List<Element> orig) {
            super(orig);
        }

        @Override
        public ELEM transform(Element listItem) {
            return createElement(listItem);
        }
    }
    
    protected ELEM createElement(Element el) {
        return (ELEM)new NameLinkElem(el);
    }

}
