/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2010 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 *  GPLv3 + Classpath exception
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package it.geosolutions.geoserver.rest.decoder;

import it.geosolutions.geoserver.rest.decoder.utils.NameLinkElem;
import it.geosolutions.geoserver.rest.decoder.utils.JDOMBuilder;
import org.jdom.Element;

/**
 * Parses list of summary data about Coverages
 *
 * <P>This is the XML REST representation:
 * <PRE>{@code <coverages>
  <coverage>
    <name>5-25-1-120-11-DOF</name>
    <atom:link 
        xmlns:atom="http://www.w3.org/2005/Atom" 
        rel="alternate" 
        href="http://localhost:8080/geoserver/rest/workspaces/pippo/coveragestores/pippoLayer/coverages/5-25-1-120-11-DOF.xml" 
        type="application/xml"/>
  </coverage>
</coverages>
 *
}</PRE>
 *
 * @author ETj (etj at geo-solutions.it)
 */
public class RESTCoverageList extends RESTAbstractList<NameLinkElem> {

    public static RESTCoverageList build(String response) {
        Element elem = JDOMBuilder.buildElement(response);
        return elem == null? null : new RESTCoverageList(elem);
	}

    protected RESTCoverageList(Element list) {
        super(list);
    }
    
}
