/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2010 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 *  GPLv3 + Classpath exception
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package it.geosolutions.geoserver.rest.decoder;

import it.geosolutions.geoserver.rest.decoder.utils.JDOMBuilder;
import org.jdom.Element;

/**
 * Parse <TT>CoverageStore</TT>s returned as XML REST objects.
 * <P>
 * This is the XML document returned by GeoServer when requesting a CoverageStore:
 * <PRE>
 * {@code 
 * <coverageStore>
 *      <name>testRESTStoreGeotiff</name>
 *      <type>GeoTIFF</type>
 *      <enabled>true</enabled>
 *      <workspace>
 *          <name>it.geosolutions</name>
 *          <href>http://localhost:8080/geoserver/rest/workspaces/it.geosolutions.xml</href>
 *      </workspace>
 *      <url>file:/home/geosolutions/prj/git/gman/target/test-classes/testdata/resttestdem.tif</url>
 *      <coverages>
 *          <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate"
 *              href="http://localhost:8080/geoserver/rest/workspaces/it.geosolutions/coveragestores/testRESTStoreGeotiff/external/coverages.xml"
 *              type="application/xml"/>
 *      </coverages>
 * </coverageStore>
 * }
 * </PRE>
 *
 * <I>Note: the whole XML fragment is stored in memory. At the moment, there are
 * methods to retrieve only the more useful data.
 * 
 * @author etj
 */
public class RESTCoverageStore {
	private final Element cs;


	public RESTCoverageStore(Element cs) {
		this.cs = cs;
	}

    public static RESTCoverageStore build(String response) {
        if(response == null)
            return null;

        Element pb = JDOMBuilder.buildElement(response);
        if(pb != null)
            return new RESTCoverageStore(pb);
        else
            return null;
	}

	public String getName() {
		return cs.getChildText("name");
	}

	public String getWorkspaceName() {
		return cs.getChild("workspace").getChildText("name");
	}

    public String toString() {
        StringBuilder sb = new StringBuilder(getClass().getSimpleName())
                .append('[');
        if(cs == null)
            sb.append("null");
        else
            sb.append("name:").append(getName())
                .append(" wsname:").append(getWorkspaceName());

        return sb.toString();
    }
}
