/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2010 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 *  GPLv3 + Classpath exception
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package it.geosolutions.geoserver.rest.decoder;

import it.geosolutions.geoserver.rest.decoder.utils.JDOMBuilder;
import org.jdom.Element;

/**
 * Parse <TT>Layer</TT>s returned as XML REST objects.
 *
 * <P>This is the XML REST representation:
 * <PRE>
 * {@code
<layerGroup>
  <name>tasmania</name>
  <layers>
    <layer>
      <name>tasmania_state_boundaries</name>
      <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate" href="http://localhost:8080/geoserver/rest/layers/tasmania_state_boundaries.xml" type="application/xml"/>
    </layer>
    <layer>
      <name>tasmania_water_bodies</name>
      <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate" href="http://localhost:8080/geoserver/rest/layers/tasmania_water_bodies.xml" type="application/xml"/>
    </layer>
    <layer>
      <name>tasmania_roads</name>
      <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate" href="http://localhost:8080/geoserver/rest/layers/tasmania_roads.xml" type="application/xml"/>
    </layer>
    <layer>
      <name>tasmania_cities</name>
      <atom:link xmlns:atom="http://www.w3.org/2005/Atom" rel="alternate" href="http://localhost:8080/geoserver/rest/layers/tasmania_cities.xml" type="application/xml"/>
    </layer>
  </layers>
  <styles>
    <style/>
    <style/>
    <style/>
    <style/>
  </styles>
  <bounds>
    <minx>143.83482400000003</minx>
    <maxx>148.47914100000003</maxx>
    <miny>-43.648056</miny>
    <maxy>-39.573891</maxy>
    <crs>EPSG:4326</crs>
  </bounds>
  <metadata>
    <entry key="rawStyleList"></entry>
  </metadata>
</layerGroup>
 * }</PRE>
 * @author etj
 */

public class RESTLayerGroup {
	private final Element rootElem;

    public static RESTLayerGroup build(String response) {
        Element elem = JDOMBuilder.buildElement(response);
        return elem == null? null : new RESTLayerGroup(elem);
	}

	public RESTLayerGroup(Element layerElem) {
		this.rootElem = layerElem;
	}

	public String getName() {
		return rootElem.getChildText("name");
	}

	public RESTLayerList getLayerList() {
        return new RESTLayerList(rootElem.getChild("layers"));
	}

	public String getCRS() {
		Element bounds = rootElem.getChild("bounds");
		return bounds.getChildText("crs");
	}

	protected double getBound(String edge) {
		Element bounds = rootElem.getChild("bounds");
		return Double.parseDouble(bounds.getChildText(edge));
	}

	public double getMinX() {
		return getBound("minx");
	}
	public double getMaxX() {
		return getBound("maxx");
	}
	public double getMinY() {
		return getBound("miny");
	}
	public double getMaxY() {
		return getBound("maxy");
	}
}
