/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *  
 *  Copyright (C) 2010 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 *  GPLv3 + Classpath exception
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package it.geosolutions.geoserver.rest.decoder;

import it.geosolutions.geoserver.rest.decoder.utils.JDOMBuilder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

import org.jdom.Element;

/**
 * Parses list of summary data about Namespaces.
 * <BR>Single items are handled by {@link RESTShortNamespace}.
 *
 * @author ETj (etj at geo-solutions.it)
 */
public class RESTNamespaceList implements Iterable<RESTNamespaceList.RESTShortNamespace> {

    private final List<Element> nsList;

    public static RESTNamespaceList build(String response) {
        if(response == null)
            return null;

        Element elem = JDOMBuilder.buildElement(response);
        if(elem != null)
            return new RESTNamespaceList(elem);
        else
            return null;
	}

    protected RESTNamespaceList(Element wslistroot) {
        List<Element> tmpList = new ArrayList<Element>();
        for (Element wselem : (List<Element>) wslistroot.getChildren("namespace")) {
            tmpList.add(wselem);
        }

        nsList = Collections.unmodifiableList(tmpList);
    }

    public int size() {
        return nsList.size();
    }

    public boolean isEmpty() {
        return nsList.isEmpty();
    }

    public RESTShortNamespace get(int index) {
        return new RESTShortNamespace(nsList.get(index));
    }

    public Iterator<RESTShortNamespace> iterator() {
        return new RESTNSListIterator(nsList);
    }


    private static class RESTNSListIterator implements Iterator<RESTShortNamespace> {

        private final Iterator<Element> iter;

        public RESTNSListIterator(List<Element> orig) {
            iter = orig.iterator();
        }        

        public boolean hasNext() {
            return iter.hasNext();
        }

        public RESTShortNamespace next() {
            return new RESTShortNamespace(iter.next());
        }

        public void remove() {
            throw new UnsupportedOperationException("Not supported.");
        }
    }

    /**
     * Namespace summary info.
     * <BR>This is an XML fragment:
     *
     * <PRE>
     * {@code
     *   <namespace>
     *      <name>it.geosolutions</name>
     *      <atom:link xmlns:atom="http://www.w3.org/2005/Atom"
     *          rel="alternate"
     *          href="http://localhost:8080/geoserver/rest/namespaces/it.geosolutions.xml"
     *          type="application/xml"/>
     *  </namespace>
     * }
     * </PRE>
     */

    public static class RESTShortNamespace {
        private final Element nsElem;

        public RESTShortNamespace(Element elem) {
            this.nsElem = elem;
        }

        public String getName() {
            return nsElem.getChildText("name");
        }
    }

}
