/*
 *  GeoServer-Manager - Simple Manager Library for GeoServer
 *
 *  Copyright (C) 2010 GeoSolutions S.A.S.
 *  http://www.geo-solutions.it
 *
 *  GPLv3 + Classpath exception
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package it.geosolutions.geoserver.rest.decoder;

import it.geosolutions.geoserver.rest.decoder.utils.JDOMBuilder;
import org.jdom.Element;
import org.jdom.Namespace;

/**
 * Parse a resource (FeatureType or coverage) returned as XML REST objects.
 *
 * @author etj
 */
public class RESTResource {
	protected final Element rootElem;

    public static RESTResource build(String response) {
        Element elem = JDOMBuilder.buildElement(response);
        return elem == null? null : new RESTCoverage(elem);
	}

	public RESTResource(Element resource) {
		this.rootElem = resource;
	}

	public String getName() {
		return rootElem.getChildText("name");
	}

    public String getTitle() {
		return rootElem.getChildText("title");
	}

	public String getNativeName() {
		return rootElem.getChildText("nativeName");
	}

	public String getAbstract() {
		return rootElem.getChildText("abstract");
	}

	public String getNameSpace() {
		return rootElem.getChild("namespace").getChildText("name");
	}

	public String getStoreName() {
		return rootElem.getChild("store").getChildText("name");
	}

	public String getStoreType() {
		return rootElem.getChild("store").getAttributeValue("class");
	}

    public String getStoreUrl() {
		Element store = rootElem.getChild("store");
        Element atom = store.getChild("link", Namespace.getNamespace("atom", "http://www.w3.org/2005/Atom"));
        return atom.getAttributeValue("href");
    }

	public String getCRS() {
		Element elBBox = rootElem.getChild("latLonBoundingBox");
		return elBBox.getChildText("crs");
	}

	protected double getLatLonEdge(String edge) {
		Element elBBox = rootElem.getChild("latLonBoundingBox");
		return Double.parseDouble(elBBox.getChildText(edge));
	}

	public double getMinX() {
		return getLatLonEdge("minx");
	}
	public double getMaxX() {
		return getLatLonEdge("maxx");
	}
	public double getMinY() {
		return getLatLonEdge("miny");
	}
	public double getMaxY() {
		return getLatLonEdge("maxy");
	}
}
